#version 120

// Define BLOOM to enable bloom effect
//#define BLOOM  // Uncomment to enable bloom

// Uniforms
uniform sampler2D colortex0;
uniform float viewWidth;
uniform float viewHeight;

// Varyings
varying vec2 texcoord;

// Utility functions
float avg3(vec3 vec) {
    return (vec.x + vec.y + vec.z) / 3.0;
}

// Bloom function
void Bloom(inout vec3 color) {
    #ifdef BLOOM
    vec3 blur = vec3(0.0);
    int quality = 10;  // Fixed quality
    float range = 8.0; // Fixed range
    float halfQuality = quality / 2.0 - 0.5;
    float totalStrength = 0.0;

    for (int i = 0; i < quality; i++) {
        for (int j = 0; j < quality; j++) {
            vec2 offset = vec2((i - halfQuality) * range / viewWidth, (j - halfQuality) * range / viewHeight);
            float dist = 1.33 - distance(vec2(halfQuality), vec2(i, j)) / halfQuality;
            float strength = dist;
            blur += texture2D(colortex0, texcoord + offset).rgb * strength;
            totalStrength += strength;
        }
    }

    blur /= totalStrength;
    float avg = avg3(blur);
    blur = mix(vec3(avg), blur, 2.0);
    blur = clamp(blur, 0.0, 1.0);
    color = mix(color, blur, 0.36); // Fixed bloom strength
    #endif
}

// Gamma adjustment function
void AdjustGamma(inout vec3 color) {
    color = pow(color, vec3(1.0 - 0.60 + 0.5)); // Fixed gamma value
}

// Main function
void main() {
    vec3 color = texture2D(colortex0, texcoord).rgb;
    Bloom(color);
    AdjustGamma(color);
    gl_FragColor = vec4(color, 1.0);
}
